# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`simp_options`](#simp_options): Sets up variables that enable core SIMP capabilities or provide site configuration larger than the scope of a single module
* [`simp_options::dns`](#simp_options--dns): Sets up DNS configuration variables
* [`simp_options::gid`](#simp_options--gid): Provides system-wide defaults for GID settings
* [`simp_options::ldap`](#simp_options--ldap): Sets up LDAP configuration variables
* [`simp_options::ntp`](#simp_options--ntp): Sets up NTP configuration variables
* [`simp_options::ntpd`](#simp_options--ntpd): Sets up NTP configuration variables
* [`simp_options::openssl`](#simp_options--openssl): Sets up OpenSSL configuration variables
* [`simp_options::openssl::params`](#simp_options--openssl--params): Sets appropriate openssl cipher suite based on whether FIPS-mode is
* [`simp_options::pki`](#simp_options--pki): Sets up global PKI configuration variables
* [`simp_options::puppet`](#simp_options--puppet): Sets up Puppet configuration variables
* [`simp_options::rsync`](#simp_options--rsync): Sets up ``rsync`` configuration variables
* [`simp_options::syslog`](#simp_options--syslog): Sets up ``syslog`` configuration variables
* [`simp_options::uid`](#simp_options--uid): Provides system-wide defaults for UID settings

## Classes

### <a name="simp_options"></a>`simp_options`

Sets up variables that enable core SIMP capabilities or provide site configuration larger than the scope of a single module

#### Parameters

The following parameters are available in the `simp_options` class:

* [`auditd`](#-simp_options--auditd)
* [`clamav`](#-simp_options--clamav)
* [`fips`](#-simp_options--fips)
* [`firewall`](#-simp_options--firewall)
* [`haveged`](#-simp_options--haveged)
* [`ipsec`](#-simp_options--ipsec)
* [`kerberos`](#-simp_options--kerberos)
* [`ldap`](#-simp_options--ldap)
* [`logrotate`](#-simp_options--logrotate)
* [`pam`](#-simp_options--pam)
* [`authselect`](#-simp_options--authselect)
* [`pki`](#-simp_options--pki)
* [`sssd`](#-simp_options--sssd)
* [`stunnel`](#-simp_options--stunnel)
* [`syslog`](#-simp_options--syslog)
* [`tcpwrappers`](#-simp_options--tcpwrappers)
* [`trusted_nets`](#-simp_options--trusted_nets)
* [`package_ensure`](#-simp_options--package_ensure)
* [`libkv`](#-simp_options--libkv)

##### <a name="-simp_options--auditd"></a>`auditd`

Data type: `Boolean`

Include SIMP's ``auditd`` class and add audit rules pertinent to each
application

Default value: `false`

##### <a name="-simp_options--clamav"></a>`clamav`

Data type: `Boolean`

Deprecated - DO NOT USE

Default value: `false`

##### <a name="-simp_options--fips"></a>`fips`

Data type: `Boolean`

Enable ``FIPS`` mode for the system

This parameter enforces strict compliance with ``FIPS-140-2``.

All core SIMP modules can support this configuration. It is important that
you know the security tradeoffs of ``FIPS-140-2`` compliance.

``FIPS`` mode disables the use of ``MD5`` and may require weaker ciphers or
key lengths than your security policies allow.

@see http://simp.readthedocs.io/en/stable/security_mapping/components/simp/cryptographic_protection/control.html SIMP - Security Control Mapping Cryptographic Protection

Default value: `false`

##### <a name="-simp_options--firewall"></a>`firewall`

Data type: `Boolean`

Indicate that you want to load the native SIMP firewall management subsystem

Default value: `false`

##### <a name="-simp_options--haveged"></a>`haveged`

Data type: `Boolean`

Include the ``haveged`` class to ensure adequate entropy for key
generation

@see http://simp.readthedocs.io/en/stable/getting_started_guide/Installation_Options/ISO/ISO_Build/Environment_Preparation.html?highlight=haveged SIMP - Getting Started Environment Preparation

Default value: `false`

##### <a name="-simp_options--ipsec"></a>`ipsec`

Data type: `Boolean`

Include SIMP's ``ipsec`` class, ``libreswan``, and add rules pertinent to
each application

Default value: `false`

##### <a name="-simp_options--kerberos"></a>`kerberos`

Data type: `Boolean`

Include the SIMP's Kerberos class, ``krb5``, and to use ``Kerberos`` in
applicable modules

Default value: `false`

##### <a name="-simp_options--ldap"></a>`ldap`

Data type: `Boolean`

Encourage modules to use ``LDAP`` support where possible

Default value: `false`

##### <a name="-simp_options--logrotate"></a>`logrotate`

Data type: `Boolean`

Include SIMP's ``logrotate`` class and add rules pertinent to each
application

Default value: `false`

##### <a name="-simp_options--pam"></a>`pam`

Data type: `Boolean`

Include SIMP's ``pam`` class SIMP to manage ``PAM``

Default value: `false`

##### <a name="-simp_options--authselect"></a>`authselect`

Data type: `Boolean`

The dconf, pam, and nsswitch modules will be configured to work with
a system leveraging authselect

Default value: `false`

##### <a name="-simp_options--pki"></a>`pki`

Data type: `Variant[Boolean,Enum['simp']]`

Include SIMP's ``pki`` class and use ``pki::copy`` to distribute PKI
certificates to the correct locations

* If ``false``, don't include SIMP's ``pki`` class, and don't use
  ``pki::copy``
* If ``true``,  don't include SIMP's ``pki`` class, but do use ``pki::copy``
* If ``simp``, include SIMP's ``pki`` class, and use ``pki::copy``

Default value: `false`

##### <a name="-simp_options--sssd"></a>`sssd`

Data type: `Boolean`

Enable ``SSSD`` support where possible

Default value: `false`

##### <a name="-simp_options--stunnel"></a>`stunnel`

Data type: `Boolean`

Include SIMP's ``stunnel`` class and use it to secure server-to-server
communications in applicable modules

Default value: `false`

##### <a name="-simp_options--syslog"></a>`syslog`

Data type: `Boolean`

Include SIMP's ``rsyslog`` class and configure RSyslog application hooks

Default value: `false`

##### <a name="-simp_options--tcpwrappers"></a>`tcpwrappers`

Data type: `Boolean`

Whether to include SIMP's ``tcpwrappers`` class and use
``tcpwrappers::allow`` to permit the application to the subnets in
``$simp_options::trusted_nets``

Default value: `false`

##### <a name="-simp_options--trusted_nets"></a>`trusted_nets`

Data type: `Simplib::Netlist`

Subnets to permit, in ``CIDR`` notation

* If you need this to be more (or less) restrictive for a given class, you
  can override it for the specific class via that class' parameters.

Default value: `['127.0.0.1', '::1']`

##### <a name="-simp_options--package_ensure"></a>`package_ensure`

Data type: `String`

The default ensure parameter for packages

* Can be either ``latest`` or ``installed``

Default value: `'latest'`

##### <a name="-simp_options--libkv"></a>`libkv`

Data type: `Boolean`

Enable the libkv backend for some functions

Default value: `false`

### <a name="simp_options--dns"></a>`simp_options::dns`

Sets up DNS configuration variables

#### Parameters

The following parameters are available in the `simp_options::dns` class:

* [`search`](#-simp_options--dns--search)
* [`servers`](#-simp_options--dns--servers)

##### <a name="-simp_options--dns--search"></a>`search`

Data type: `Array[String]`

The DNS search list. Remember to put these in the appropriate
order for your environment.

Default value: `[]`

##### <a name="-simp_options--dns--servers"></a>`servers`

Data type: `Array[Simplib::Host]`

The list of DNS servers for the managed hosts.

If the first entry of this list is set to ``127.0.0.1``, then all clients
will configure themselves as caching DNS servers pointing to the other
entries in the list.

---------------------------------------------------------------------------
If you are using the SIMP ``resolv`` module, and the system is a DNS server
using the SIMP ``named`` module but you wish to have your node point to a
different DNS server for primary DNS resolution, then you MUST set
``resolv::named_server`` to ``true`` via Hiera.

This will get around the convenience logic that was put in place to handle
the caching entries and will not attempt to convert your system to a
caching DNS server.

---------------------------------------------------------------------------

Default value: `[]`

### <a name="simp_options--gid"></a>`simp_options::gid`

Provides system-wide defaults for GID settings

#### Parameters

The following parameters are available in the `simp_options::gid` class:

* [`min`](#-simp_options--gid--min)
* [`max`](#-simp_options--gid--max)

##### <a name="-simp_options--gid--min"></a>`min`

Data type: `Integer[0]`

The lowest allowed regular user GID for the system

Default value: `pick(fact('login_defs.gid_min'), 1000)`

##### <a name="-simp_options--gid--max"></a>`max`

Data type: `Optional[Integer[1]]`

The highest allowed regular user GID for the system

* If not defined, applications should simply do what makes sense for them
  internally

Default value: `fact('login_defs.gid_max')`

### <a name="simp_options--ldap"></a>`simp_options::ldap`

Some parameters have default values in `simp_options/data/ldap.yaml`, all
others **must** have a value specified via Hiera or your ENC.

#### Parameters

The following parameters are available in the `simp_options::ldap` class:

* [`base_dn`](#-simp_options--ldap--base_dn)
* [`bind_dn`](#-simp_options--ldap--bind_dn)
* [`bind_pw`](#-simp_options--ldap--bind_pw)
* [`bind_hash`](#-simp_options--ldap--bind_hash)
* [`sync_dn`](#-simp_options--ldap--sync_dn)
* [`sync_pw`](#-simp_options--ldap--sync_pw)
* [`sync_hash`](#-simp_options--ldap--sync_hash)
* [`root_dn`](#-simp_options--ldap--root_dn)
* [`master`](#-simp_options--ldap--master)
* [`uri`](#-simp_options--ldap--uri)

##### <a name="-simp_options--ldap--base_dn"></a>`base_dn`

Data type: `String`

The Base Distinguished Name of the LDAP server

Default value: `simplib::ldap::domain_to_dn()`

##### <a name="-simp_options--ldap--bind_dn"></a>`bind_dn`

Data type: `String`

The LDAP Bind Distinguished Name

Default value: `"cn=hostAuth,ou=Hosts,${base_dn}"`

##### <a name="-simp_options--ldap--bind_pw"></a>`bind_pw`

Data type: `String`

The LDAP Bind password

##### <a name="-simp_options--ldap--bind_hash"></a>`bind_hash`

Data type: `String`

The salted LDAP Bind password hash

##### <a name="-simp_options--ldap--sync_dn"></a>`sync_dn`

Data type: `String`

The LDAP Sync Distinguished Name

Default value: `"cn=LDAPSync,ou=Hosts,${base_dn}"`

##### <a name="-simp_options--ldap--sync_pw"></a>`sync_pw`

Data type: `String`

The LDAP Sync password

##### <a name="-simp_options--ldap--sync_hash"></a>`sync_hash`

Data type: `String`

The LDAP Sync password hash

##### <a name="-simp_options--ldap--root_dn"></a>`root_dn`

Data type: `String`

The LDAP Root Distinguished Name

Default value: `"cn=LDAPAdmin,ou=People,${base_dn}"`

##### <a name="-simp_options--ldap--master"></a>`master`

Data type: `Simplib::URI`

The LDAP master in URI form (ldap://server)

Default value: `$simp_options::puppet::server ? { undef => undef, default => "ldap://${simp_options::puppet::server}"`

##### <a name="-simp_options--ldap--uri"></a>`uri`

Data type: `Array[Simplib::URI]`

The list of OpenLDAP servers in URI form (ldap://server)

Default value: `$master ? { undef => undef, default => [$master]`

### <a name="simp_options--ntp"></a>`simp_options::ntp`

@example A hash of servers
  {
    'ntp1.example.com' => [
      'minpoll 3',
      'maxpoll 6',
    ],
    'ntp2.example.com' => [
      'iburst',
      'minpoll 4',
      'maxpoll 8',
    ]
  }

#### Examples

##### An array of servers

```puppet
[
  'ntp1.example.com',
  'ntp2.example.com',
]
```

#### Parameters

The following parameters are available in the `simp_options::ntp` class:

* [`servers`](#-simp_options--ntp--servers)

##### <a name="-simp_options--ntp--servers"></a>`servers`

Data type: `Variant[Hash[Simplib::Host, Array[String[1]]], Array[Simplib::Host]]`

The NTP time servers for the network and, optionally,
configuration for the daemons that communicate with them.

A consistent time source is critical to your systems' security. **DO NOT**
run multiple production systems using individual hardware clocks!

Default value: `[]`

### <a name="simp_options--ntpd"></a>`simp_options::ntpd`

Sets up NTP configuration variables

#### Parameters

The following parameters are available in the `simp_options::ntpd` class:

* [`servers`](#-simp_options--ntpd--servers)

##### <a name="-simp_options--ntpd--servers"></a>`servers`

Data type: `Array[Simplib::Host]`

**DEPRECATED** Use simp_options::ntp instead.
The list of NTP time servers for the network.
A consistent time source is critical to your systems' security. **DO NOT**
run multiple production systems using individual hardware clocks!

Default value: `[]`

### <a name="simp_options--openssl"></a>`simp_options::openssl`

Sets up OpenSSL configuration variables

* **See also**
  * https://wiki.openssl.org/index.php/Command_Line_Utilities#ciphers
    * OpenSSL Ciphers Command

#### Parameters

The following parameters are available in the `simp_options::openssl` class:

* [`cipher_suite`](#-simp_options--openssl--cipher_suite)

##### <a name="-simp_options--openssl--cipher_suite"></a>`cipher_suite`

Data type: `Array[String]`

The default ciphers to use in openssl.

Default value: `$::simp_options::openssl::params::cipher_suite`

### <a name="simp_options--openssl--params"></a>`simp_options::openssl::params`

desired or the system is already in FIPS mode.

### <a name="simp_options--pki"></a>`simp_options::pki`

Sets up global PKI configuration variables

#### Parameters

The following parameters are available in the `simp_options::pki` class:

* [`source`](#-simp_options--pki--source)

##### <a name="-simp_options--pki--source"></a>`source`

Data type: `Stdlib::Absolutepath`

The source location for PKI certificates.  This is the source
directory for pki::copy.

Default value: `'/etc/pki/simp/x509'`

### <a name="simp_options--puppet"></a>`simp_options::puppet`

Sets up Puppet configuration variables

#### Parameters

The following parameters are available in the `simp_options::puppet` class:

* [`server`](#-simp_options--puppet--server)
* [`ca`](#-simp_options--puppet--ca)
* [`ca_port`](#-simp_options--puppet--ca_port)
* [`server_distribution`](#-simp_options--puppet--server_distribution)

##### <a name="-simp_options--puppet--server"></a>`server`

Data type: `Optional[Simplib::Host]`

The ``Hostname`` or ``FQDN`` of the Puppet server

Default value: `undef`

##### <a name="-simp_options--puppet--ca"></a>`ca`

Data type: `Optional[Simplib::Host]`

The Puppet Certificate Authority

Default value: `undef`

##### <a name="-simp_options--puppet--ca_port"></a>`ca_port`

Data type: `Simplib::Port`

The port on which the Puppet Certificate Authority will listen

Default value: `$server_distribution ? { 'PE' => $facts['puppet_settings']['agent']['ca_port'], default => 8141`

##### <a name="-simp_options--puppet--server_distribution"></a>`server_distribution`

Data type: `Simplib::Serverdistribution`

The server distribution being used, PC1 or PE.

Default value: `(('pe_build' in  $facts) or $facts['is_pe']) ? { true => 'PE', default => 'PC1'`

### <a name="simp_options--rsync"></a>`simp_options::rsync`

Sets up ``rsync`` configuration variables

#### Parameters

The following parameters are available in the `simp_options::rsync` class:

* [`server`](#-simp_options--rsync--server)
* [`timeout`](#-simp_options--rsync--timeout)

##### <a name="-simp_options--rsync--server"></a>`server`

Data type: `Simplib::Host`

Server to use for the simp::rsync_server class.

This class is used by several SIMP modules to efficiently synchronize large
data files using ``rsync`` over ``stunnel``.

The **default value** of ``127.0.0.1`` is appropriate for rsync over stunnel.

Default value: `'127.0.0.1'`

##### <a name="-simp_options--rsync--timeout"></a>`timeout`

Data type: `Integer`

rsync connection timeout in **seconds**

Default value: `1`

### <a name="simp_options--syslog"></a>`simp_options::syslog`

Sets up ``syslog`` configuration variables

#### Parameters

The following parameters are available in the `simp_options::syslog` class:

* [`log_servers`](#-simp_options--syslog--log_servers)
* [`failover_log_servers`](#-simp_options--syslog--failover_log_servers)

##### <a name="-simp_options--syslog--log_servers"></a>`log_servers`

Data type: `Array[Simplib::Host]`

The log servers to receive forwarded logs

Default value: `[]`

##### <a name="-simp_options--syslog--failover_log_servers"></a>`failover_log_servers`

Data type: `Array[Simplib::Host]`

Failover log servers in case your log servers fail

Default value: `[]`

### <a name="simp_options--uid"></a>`simp_options::uid`

Provides system-wide defaults for UID settings

#### Parameters

The following parameters are available in the `simp_options::uid` class:

* [`min`](#-simp_options--uid--min)
* [`max`](#-simp_options--uid--max)

##### <a name="-simp_options--uid--min"></a>`min`

Data type: `Integer[0]`

The lowest allowed regular user UID for the system

Default value: `pick(fact('login_defs.uid_min'), 1000)`

##### <a name="-simp_options--uid--max"></a>`max`

Data type: `Optional[Integer[1]]`

The highest allowed regular user UID for the system

* If not defined, applications should simply do what makes sense for them
  internally

Default value: `fact('login_defs.uid_max')`

